#version 150

uniform sampler2D Sampler0;
uniform vec4 ColorModulator;
uniform float GameTime;

in vec3 Position;
in vec2 texCoord0;
in vec4 vertexColor;
in float isSlot;

out vec4 fragColor;

// Simple pseudo-random function
float random(vec2 st) {
    return fract(sin(dot(st.xy, vec2(12.9898, 78.233))) * 43758.5453);
}

// 2D Value Noise
float noise(vec2 st) {
    vec2 i = floor(st);
    vec2 f = fract(st);

    // Four corners in 2D of a tile
    float a = random(i);
    float b = random(i + vec2(1.0, 0.0));
    float c = random(i + vec2(0.0, 1.0));
    float d = random(i + vec2(1.0, 1.0));

    // Smooth interpolation
    vec2 u = f * f * (3.0 - 2.0 * f);

    // Mix 4 corners
    return mix(a, b, u.x) +
           (c - a) * u.y * (1.0 - u.x) +
           (d - b) * u.x * u.y;
}

void main() {
    vec4 color = texture(Sampler0, texCoord0) * vertexColor;
    if (color.a == 0.0) {
        discard;
    }

    // Hide other highlights
    if (color.xyz == vec3(0.9960784314, 0.9960784314, 0.9960784314)) {
        if (isSlot == 1.0) {
            color = vec4(1, 1, 1, sin(GameTime * 5000) * 0.1 + 0.3);
        } else {
            discard;
        }
    }
    if (color.xyz == vec3(1,0.9098039216,0)) {
        float dir = 0;
        float speed = 20;
        float strength = -0.1;
        
        for (int i = 0; i < 7; i++) {
            dir += 60;
            vec2 movingUV = texCoord0 + vec2(GameTime * sin(dir)*speed, GameTime * cos(dir)*speed);
            float noiseValue = noise(movingUV * 100.0);

            color.xyz += vec3(noiseValue * strength, noiseValue * strength, noiseValue * strength);
        }
    }
    

    fragColor = color * ColorModulator;
}