import json
import math
import os

lang = "da_dk.json"  # Change this to your language

def split_text(count, string):
    step = len(string) / count
    revealed_strings = []
    for i in range(count):
        cur = int(math.ceil(step * (i + 1)))
        revealed_strings.append(string[:cur])
    return revealed_strings

def gradual_reveal(strings, repeat_counts, keys, prefix="bungeon.dialogue."):
    updated_data = {}  # To store updated values during the reveal
    for idx, (string, repeat_count) in enumerate(zip(strings, repeat_counts)):
        revealed_steps = split_text(repeat_count, string)
        for i, revealed in enumerate(revealed_steps[:-1]):  # Exclude the last iteration
            updated_data[prefix + keys[idx] + f"_{i}"] = revealed
    return updated_data

def append_to_json(file_path, updated_data):
    with open(file_path, 'r') as file:
        original_content = file.read()

    json_end_index = original_content.rfind("}")
    formatted_data = json.dumps(updated_data, indent=4)[1:-1]  # Remove outer braces

    # Fix indentation: Replace 4 spaces with a single tab
    formatted_data = formatted_data.replace("    ", "\t")

    # Remove trailing whitespace from the original content
    original_content = original_content[:json_end_index].rstrip()

    # Add two newlines between the user-made content and the generated content
    updated_content = (
        original_content +  # Existing content without trailing whitespace
        ",\n\n" +  # Add a comma and two newlines
        formatted_data + "\n}"  # Add the formatted data and the closing brace
    )

    with open(file_path, 'w') as file:
        file.write(updated_content)

def main():
    # Get the directory where the script is located
    script_dir = os.path.dirname(os.path.abspath(__file__))

    # Navigate to the parent folder
    parent_dir = os.path.dirname(script_dir)

    # Define the path to the language file
    lang_file = os.path.join(parent_dir, lang)

    # Load the language file
    with open(lang_file, "r") as file:
        data = json.load(file)
    
    # Define input keys and repeat counts
    input_keys = [
        "tutorial.intro0", "tutorial.intro1", "tutorial.intro2", "tutorial.intro3", "tutorial.explain0", "tutorial.explain1", "tutorial.explain2", "tutorial.sword0",
        "tutorial.sword1", "tutorial.upgrade0", "tutorial.upgrade1", "tutorial.outro0", "tutorial.outro1", "post_golem.0", "post_golem.1", "post_golem.2", "post_golem.3",
        "post_golem.first_run", "post_golem.many_runs"
    ]
    input_strings = [data.get("bungeon.dialogue." + key, "") for key in input_keys]
    repeat_counts = [17, 32, 8, 35, 25, 26, 28, 27, 28, 33, 31, 22, 5, 19, 21, 26, 28, 23, 13]

    # Generate updated data
    updated_data = gradual_reveal(input_strings, repeat_counts, input_keys)

    # Append updated data to the language file
    append_to_json(lang_file, updated_data)

if __name__ == "__main__":
    main()
    print("Filled dialogue in", lang)